@@ -4,7 +4,29 @@ from matflow.scripting import main_func
 
 @main_func
 def fit_yield_function(yield_function_name, yield_point_criteria, uniaxial_response,
-                       multiaxial_responses, fixed_parameters):
+                       multiaxial_responses, fixed_parameters, initial_parameters,
+                       opt_parameters):
+    """
+    Parameters
+    ----------
+    yield_function_name : str
+    yield_point_criteria : dict
+    uniaxial_response :  dict
+    multiaxial_responses : list of dict
+    fixed_parameters : dict
+    initial_parameters: dict
+    opt_parameters : dict
+        Optimisation parameters. Dict with any of the keys:
+            default_bounds : list of length two, optional
+                The bounds applied to all non-fixed yield function parameters by
+                default.
+            bounds : dict, optional
+                Dict of bounds for individual named parameters. These bounds take
+                precedence over `default_bounds`.
+            **kwargs : dict
+                Other parameters to be passed to the SciPy least_squares function.    
+
+    """
 
     # Generate LoadResponse objects:
     uni_resp = LoadResponse(
@@ -24,14 +46,10 @@ def fit_yield_function(yield_function_name, yield_point_criteria, uniaxial_respo
     response_set.fit_yield_function(
         yield_function_name,
         uniaxial_response=uni_resp,
+        initial_params=initial_parameters,
+        opt_params=opt_parameters,
         **(fixed_parameters or {}),
     )
-    fitted_yield_functions = [
-        {
-            'name': yield_function_name,
-            **i['yield_function'].get_parameters()
-        }
-        for i in response_set.yield_functions
-    ]
+    fitted_yield_functions = response_set.to_dict()
 
     return fitted_yield_functions
