@@ -4,7 +4,7 @@ from matflow.scripting import main_func
 
 @main_func
 def get_load_case_biaxial(total_times, num_increments, directions, target_strain_rates,
-                          target_strains, dump_frequency):
+                          target_strains, rotations, dump_frequency):
 
     if target_strains is None:
         target_strains = [None] * len(total_times)
@@ -14,13 +14,17 @@ def get_load_case_biaxial(total_times, num_increments, directions, target_strain
     if dump_frequency is None:
         dump_frequency = [1] * len(total_times)
 
+    if rotations is None:
+        rotations = [None] * len(total_times)
+
     all_load_cases = []
-    for t, n, eps_dot, eps, d, freq in zip(
+    for t, n, eps_dot, eps, d, rot, freq in zip(
         total_times,
         num_increments,
         target_strain_rates,
         target_strains,
         directions,
+        rotations,
         dump_frequency,
     ):
         all_load_cases.append(
@@ -30,6 +34,7 @@ def get_load_case_biaxial(total_times, num_increments, directions, target_strain
                 direction=d,
                 target_strain_rate=eps_dot,
                 target_strain=eps,
+                rotation=rot,
                 dump_frequency=freq,
             )
         )
